darkhistory.electrons.ics.nonrel\_diff\_terms.diff\_expansion
=============================================================

.. currentmodule:: darkhistory.electrons.ics.nonrel_diff_terms

.. autofunction:: diff_expansion